/*
 *  file      : parse.h
 *  project   : xcfa
 *  with      : Gtk-2
 *
 *  copyright : (C) 2003 - 2011 by Claude Bulin
 *
 *  xcfa - GTK+ implementation of the GNU shell command
 *  GNU General Public License
 *
 *  This file is part of XCFA.
 * 
 *  XCFA is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  at your option) any later version.
 * 
 *  XCFA is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with XCFA.  If not, see <http://www.gnu.org/licenses/>.
 */


#ifndef parse_h
#define parse_h 1


typedef enum {
	PARSE_TYPE_STOCKAGE_CD = 0,
	PARSE_TYPE_TITLE_CD
} PARSE_TYPE;

void	Parse_entry( PARSE_TYPE p_ParseType );
void	Parse_remove( PARSE_TYPE p_ParseType, gboolean b_see );
void	Parse_print_cd( PARSE_TYPE p_ParseType );
gchar	*Parse_get_line( PARSE_TYPE p_ParseType, gint p_Num_cell );


#endif



